%bcond_without check

Name:           rust-packaging
Version:        26.3
Release:        %mkrel 3
Summary:        RPM macros and generators for building Rust packages
Group:          System/Packaging
License:        MIT

URL:            https://pagure.io/fedora-rust/rust-packaging
Source:         %{url}/archive/%{version}/rust-packaging-%{version}.tar.gz

# temporary patch for compatibility with RHEL / ELN:
# The %%cargo_prep macro in RHEL / ELN accepts a -V flag. Using the same spec
# file for both Fedora and ELN would cause spec file parsing errors because
# the -V flag is not known in Fedora.
Patch:          0001-Temporarily-accept-cargo_prep-V-flag-for-spec-compat.patch

Patch:          0001-tests-adapt-to-slightly-different-macro-expansion-in.patch

# Mageia specific patch to fix tests
Patch:          0001-Fix-tests-on-Mageia.patch

BuildArch:      noarch

%if %{with check}
BuildRequires:  python3-pytest
%endif

%description
%{summary}.

%if ! 0%{?rhel}
%package -n rust-srpm-macros
Summary:        RPM macros for building Rust projects

%description -n rust-srpm-macros
RPM macros for building source packages for Rust projects.
%endif

%package -n cargo-rpm-macros
Summary:        RPM macros for building projects with cargo

# obsolete + provide rust-packaging (removed in Fedora 38)
Obsoletes:      rust-packaging < 24
Provides:       rust-packaging = %{version}-%{release}

Requires:       cargo2rpm >= 0.1.8

Requires:       cargo
Requires:       gawk
Requires:       grep

%if ! 0%{?rhel}
Requires:       rust-srpm-macros = %{version}-%{release}
%else
# The "rust-srpm-macros" package is built from the "rust" source package in
# RHEL, so the package follows a different versioning scheme.
Requires:       rust-srpm-macros
%endif

%description -n cargo-rpm-macros
RPM macros for building projects with cargo.

%prep
%autosetup -p1

%build
# nothing to do

%install
install -D -p -m 0644 -t %{buildroot}/%{_rpmmacrodir} macros.d/macros.cargo
install -D -p -m 0644 -t %{buildroot}/%{_rpmmacrodir} macros.d/macros.rust
%if ! 0%{?rhel}
install -D -p -m 0644 -t %{buildroot}/%{_rpmmacrodir} macros.d/macros.rust-srpm
%endif
install -D -p -m 0644 -t %{buildroot}/%{_fileattrsdir} fileattrs/cargo.attr
install -D -p -m 0644 -t %{buildroot}/%{_fileattrsdir} fileattrs/cargo_vendor.attr

%if %{with check}
%check
export MACRO_DIR=%{buildroot}%{_rpmmacrodir}
pytest -vv
%endif

%if ! 0%{?rhel}
%files -n rust-srpm-macros
%license LICENSE
%{_rpmmacrodir}/macros.rust
%{_rpmmacrodir}/macros.rust-srpm
%endif

%files -n cargo-rpm-macros
%license LICENSE
%{_rpmmacrodir}/macros.cargo
%if 0%{?rhel}
%{_rpmmacrodir}/macros.rust
%endif
%{_fileattrsdir}/cargo.attr
%{_fileattrsdir}/cargo_vendor.attr



%changelog
* Sun Jun 29 2025 umeabot <umeabot> 26.3-3.mga10
+ Revision: 2228845
- Mageia 10 Mass Rebuild

* Thu Oct 10 2024 wally <wally> 26.3-2.mga10
+ Revision: 2104579
- add a patch to fix tests with rpm 4.20.0

* Mon Jul 01 2024 wally <wally> 26.3-1.mga10
+ Revision: 2078640
- new version 26.3
- add Mageia specific patch to fix tests

* Sun Feb 26 2023 guillomovitch <guillomovitch> 24-1.mga9
+ Revision: 1945567
- new version 24

* Mon Dec 19 2022 guillomovitch <guillomovitch> 23-1.mga9
+ Revision: 1925377
- new version 23

* Sun Oct 09 2022 guillomovitch <guillomovitch> 22-2.mga9
+ Revision: 1895728
- restore patch removing rich deps syntax, needed as long as urpmi doesn't support it

* Sat Sep 24 2022 neoclust <neoclust> 22-1.mga9
+ Revision: 1892033
- New version 22

* Sat Mar 19 2022 umeabot <umeabot> 21-2.mga9
+ Revision: 1799309
- Mageia 9 Mass Rebuild

* Thu Feb 24 2022 guillomovitch <guillomovitch> 21-1.mga9
+ Revision: 1784183
- new version 21

* Tue Feb 15 2022 guillomovitch <guillomovitch> 17-4.mga9
+ Revision: 1775704
- disable rich deps generation, as long as urpmi doesn't support them

* Sun Feb 06 2022 wally <wally> 17-3.mga9
+ Revision: 1772438
- rebuild for python3.10

* Fri Mar 19 2021 neoclust <neoclust> 17-2.mga9
+ Revision: 1705026
- Rebuild against python 3.9

* Wed Dec 30 2020 akien <akien> 17-1.mga8
+ Revision: 1665735
- Version 17

* Sun Dec 06 2020 akien <akien> 16-1.mga8
+ Revision: 1653968
- Update to 16

* Fri Oct 23 2020 akien <akien> 15-1.mga8
+ Revision: 1638906
- Update to 15

* Fri Mar 13 2020 akien <akien> 13-1.mga8
+ Revision: 1556066
- Sync with Fedora: Mon Feb 03 2020 Josh Stone <jistone@redhat.com> - 13-3
  o Update to 13
  o Use 'cargo install --no-track' with cargo 1.41

* Sun Feb 16 2020 umeabot <umeabot> 10-3.mga8
+ Revision: 1535886
- Mageia 8 Mass Rebuild

* Mon Oct 14 2019 tv <tv> 10-2.mga8
+ Revision: 1452941
- rebuild with python 3.8

* Sun Jul 07 2019 akien <akien> 10-1.mga8
+ Revision: 1419255
- Sync with Fedora: Mon Jun 24 2019 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 10-2
  o Update to 10
  o Do not use awk's inplace feature

* Sat May 11 2019 akien <akien> 9-1.mga7
+ Revision: 1397319
- Version 9

* Fri Apr 26 2019 akien <akien> 8-1.mga7
+ Revision: 1395462
- Version 8

* Fri Jan 18 2019 akien <akien> 6-5.mga7
+ Revision: 1357863
- Sync with Fedora: Fri Dec 07 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 6-18

* Wed Jan 09 2019 tv <tv> 6-4.mga7
+ Revision: 1352973
- rebuild with python 3.7

* Fri Dec 07 2018 akien <akien> 6-3.mga7
+ Revision: 1338730
- Sync with Fedora: Sat Nov 03 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 6-17

* Fri Sep 21 2018 umeabot <umeabot> 6-2.mga7
+ Revision: 1291450
- Mageia 7 Mass Rebuild

* Tue Sep 11 2018 akien <akien> 6-1.mga7
+ Revision: 1258320
- Version 6

* Thu Jan 18 2018 akien <akien> 5-1.mga7
+ Revision: 1194478
- Enforce C.UTF-8 locale to fix tests
- Version 5: https://pagure.io/fedora-rust/rust2rpm/releases

* Mon Sep 18 2017 tv <tv> 4-3.mga7
+ Revision: 1155228
- rebuild for new python

* Mon Jul 24 2017 akien <akien> 4-2.mga7
+ Revision: 1130359
- Do not provide old rust-rpm-macros
- Obsolete previous rust-rpm-macros package
- Adapt for Mageia packaging policy
- import rust-packaging from Fedora


* Sat Jul 08 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 4-2
- Include license

* Sat Jul 08 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 4-1
- Update to 4

* Fri Jun 23 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 3-5
- Explicitly set rustdoc path

* Wed Jun 21 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 3-4
- Mageia doesn't have C.UTF-8 lang

* Wed Jun 21 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 3-3
- Switch cargo_registry to /usr/share/cargo/registry

* Wed Jun 14 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 3-2
- Set C.UTF-8 for cargo inspector where python doesn't do locale coercing

* Tue Jun 13 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 3-1
- Initial package
